@@ -66,7 +66,6 @@ def create_violin(df,
                   display_box=True,
                   color=None,
                   maximum_number_violinplots=7
-
                   ):
     """
     Creates a list of violin plot figure objects
@@ -90,6 +89,17 @@ def create_violin(df,
     assert isinstance(display_box,bool), "display_box must be a boolean"
     assert isinstance(maximum_number_violinplots, int), "maximum_number_violinplots must be an integer"
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
+    assert 'numeric' in col_types.keys(), "col_types dictionary missing key numeric"
+    assert 'object' in col_types.keys(), "col_types dictionary missing key object"
+    assert 'boolean' in col_types.keys(), "col_types dictionary missing key boolean"
+    assert 'categorical' in col_types.keys(), "col_types dictionary missing key categorical"
+    assert 'datetime' in col_types.keys(), "col_types dictionary missing key datetime"
+    assert 'timedelta' in col_types.keys(), "col_types dictionary missing key timedelta"
+    assert violinmode in ['group', 'overlay'],"violinmode must be either group or overlay"
+    assert points in ['all', 'outliers', 'suspectedoutliers', False],"accepted values for points 'all', 'outliers', " \
+                                                                     "'suspectedoutliers'"
+    assert '.' not in filename, "filename doesn't need an extension"
+
     figure_list = list()
 
     numeric_cols = col_types['numeric']
@@ -97,21 +107,21 @@ def create_violin(df,
     categorical_columns = columns_with_distinct_values(df=df,
                                                        maximum_number_distinct_values=maximum_number_violinplots)
 
-    for col in numeric_cols:
-        for category in categorical_columns:
+    if len(numeric_cols) != 0 and len(categorical_columns) != 0:
+        for col in numeric_cols:
+            for category in categorical_columns:
 
-            plot = px.violin(data_frame=df,
-                             x=category,
-                             y=col,
-                             points=points,
-                             violinmode=violinmode,
-                             box=display_box,
-                             color=color,
-                             title='Violinplot showing distribution of {} across {} categories'.format(col,category))
-            figure_list.append(plot)
+                plot = px.violin(data_frame=df,
+                                 x=category,
+                                 y=col,
+                                 points=points,
+                                 violinmode=violinmode,
+                                 box=display_box,
+                                 color=color,
+                                 title='Violinplot showing distribution of {} across {} categories'.format(col,category))
+                figure_list.append(plot)
 
     if create_html:
-
         figures_to_html(figs=figure_list, filename=filename)
 
     return figure_list
@@ -125,14 +135,16 @@ def create_box(df,
                color=None,
                filename='box',
                create_html=True,
-               maximum_number_boxplots=7
+               maximum_number_boxplots=7,
+               orientation='v'
                ):
     """
     Creates a list of boxplot figure objects created for the entire dataset
     :param df: pandas dataframe
     :param col_types: dictionary that contains mapping of column type to list of column names
                     It is the output of extract_col_types in tabular module
-    :param points:str, whether to show the points in a box plot possible options are 'outliers', 'all',False, 'suspectedoutliers'
+    :param points:str, whether to show the points in a box plot possible options are 'outliers', 'all',False,
+                 'suspectedoutliers'
     :param boxmode: str, how to display the boxes in a boxplot.
                     Options are 'group' or 'overlay'. In group mode,
                     boxes are placed beside each other, in overlay mode,
@@ -142,36 +154,54 @@ def create_box(df,
     :param filename:
     :param create_html:boolean, whether to create an html file or not
     :param maximum_number_boxplots: int,
+    :param orientation: str, how the plot should be orientated, 'v' for vertical, 'h' for horizontal
     :return:
     """
     assert isinstance(df, pd.DataFrame), "df must be a pandas dataframe"
     assert isinstance(col_types, dict), "col_types must be a dictionary with column " \
                                         "name as keys and column type as value"
+    assert 'numeric' in col_types.keys(), "col_types dictionary missing key numeric"
+    assert 'object' in col_types.keys(), "col_types dictionary missing key object"
+    assert 'boolean' in col_types.keys(), "col_types dictionary missing key boolean"
+    assert 'categorical' in col_types.keys(), "col_types dictionary missing key categorical"
+    assert 'datetime' in col_types.keys(), "col_types dictionary missing key datetime"
+    assert 'timedelta' in col_types.keys(), "col_types dictionary missing key timedelta"
     assert isinstance(points, str), "points must be a string"
+    assert points in ['all', 'outliers', 'suspectedoutliers', False],"accepted values for points 'all', " \
+                                                                     "'outliers', " \
+                                                                     "'suspectedoutliers'"
     assert isinstance(boxmode, str), "boxmode must be a string"
+    assert boxmode in ['group', 'overlay'], "boxmode must be either group or overlay"
     assert isinstance(notched, bool), "notched must be a boolean"
     assert isinstance(create_html,bool), "create_html must be a boolean"
     assert isinstance(maximum_number_boxplots,int), "maximum_number_boxplots must be an integer"
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
+    assert '.' not in filename, "filename doesn't need an extension"
+    assert isinstance(orientation,str), "orientation must be a string"
+    assert orientation in ['v','h'], "options for orientation are 'v' or 'h' "
+
     figure_list = list()
     numeric_cols = col_types['numeric']
 
     categorical_columns = columns_with_distinct_values(df=df,
                                                        maximum_number_distinct_values=maximum_number_boxplots)
 
-    for col in numeric_cols:
-        for category in categorical_columns:
+    if len(numeric_cols) != 0 and len(categorical_columns) != 0:
 
-            plot = px.box(data_frame=df,
-                          x=category,
-                          y=col,
-                          points=points,
-                          boxmode=boxmode,
-                          notched=notched,
-                          color=color,
-                          title='Boxplot showing distribution of {} across {} categories'.format(col,category)
-                          )
-            figure_list.append(plot)
+        for col in numeric_cols:
+            for category in categorical_columns:
+
+                plot = px.box(data_frame=df,
+                              x=category,
+                              y=col,
+                              points=points,
+                              boxmode=boxmode,
+                              notched=notched,
+                              color=color,
+                              orientation=orientation,
+                              title='Boxplot showing distribution of {} across {} categories'.format(col,category)
+                              )
+                figure_list.append(plot)
 
     if create_html:
 
@@ -199,8 +229,16 @@ def create_treemap(df,
     assert isinstance(df, pd.DataFrame), "df must be a pandas dataframe"
     assert isinstance(create_html, bool),"create_html must be a boolean"
     assert isinstance(limit, int),"limit must be a int"
+    assert limit > 1, "limit must be at least 2, to have a meaningful hierarchical chart"
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
     assert isinstance(col_types, dict), "col_types must be a dictionary"
+    assert 'numeric' in col_types.keys(), "col_types dictionary missing key numeric"
+    assert 'object' in col_types.keys(), "col_types dictionary missing key object"
+    assert 'boolean' in col_types.keys(), "col_types dictionary missing key boolean"
+    assert 'categorical' in col_types.keys(), "col_types dictionary missing key categorical"
+    assert 'datetime' in col_types.keys(), "col_types dictionary missing key datetime"
+    assert 'timedelta' in col_types.keys(), "col_types dictionary missing key timedelta"
+    assert '.' not in filename, "filename doesn't need an extension"
 
     figure_list = list()
 
@@ -208,15 +246,16 @@ def create_treemap(df,
 
     numeric_cols = col_types['numeric']
 
-    for col in numeric_cols:
+    if len(path_list) > 1:
+        for col in numeric_cols:
 
-        plot = px.treemap(data_frame=df,
-                          path=path_list,
-                          values=col,
-                          title='Treemap of {} across paths {}'.format(col, str(path_list))
-                          )
+            plot = px.treemap(data_frame=df,
+                              path=path_list,
+                              values=col,
+                              title='Treemap of {} across paths {}'.format(col, str(path_list))
+                              )
 
-        figure_list.append(plot)
+            figure_list.append(plot)
 
     if create_html:
         figures_to_html(figs=figure_list, filename=filename)
@@ -243,8 +282,16 @@ def create_sunburst(df,
     assert isinstance(df, pd.DataFrame), "df must be a pandas dataframe"
     assert isinstance(create_html, bool),"create_html must be a boolean"
     assert isinstance(limit, int),"limit must be a int"
+    assert limit > 1, "limit must be at least 2, to have a meaningful hierarchical chart"
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
     assert isinstance(col_types, dict), "col_types must be a dictionary"
+    assert 'numeric' in col_types.keys(), "col_types dictionary missing key numeric"
+    assert 'object' in col_types.keys(), "col_types dictionary missing key object"
+    assert 'boolean' in col_types.keys(), "col_types dictionary missing key boolean"
+    assert 'categorical' in col_types.keys(), "col_types dictionary missing key categorical"
+    assert 'datetime' in col_types.keys(), "col_types dictionary missing key datetime"
+    assert 'timedelta' in col_types.keys(), "col_types dictionary missing key timedelta"
+    assert '.' not in filename, "filename doesn't need an extension"
 
     figure_list = list()
 
@@ -252,7 +299,7 @@ def create_sunburst(df,
 
     numeric_cols = col_types['numeric']
 
-    if len(path_list) >1:
+    if len(path_list) > 1:
         for col in numeric_cols:
 
             plot = px.sunburst(data_frame=df,
@@ -286,11 +333,13 @@ def create_correlation_plot(df,
     assert isinstance(create_html, bool), "create_html must be a boolean"
     assert isinstance(correlation_method, str), "correlation method must be a string"
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
+    assert '.' not in filename, "filename doesn't need an extension"
+
     figure_list = list()
-    check = check_dataframe(df=df)
+
     available_method = correlation_method in ['pearson', 'kendall', 'spearman']
 
-    if check and available_method and len(extract_numeric_cols(df=df))>1:
+    if available_method and len(extract_numeric_cols(df=df))>1:
 
         correlation = calculate_correlation(df=df, method=correlation_method)
 
@@ -307,45 +356,58 @@ def create_correlation_plot(df,
 
 def create_histogram(df,
                      numeric_cols,
-                     nbins=None,
+                     nbins=20,
                      marginal=None,
                      cumulative=False,
-                     histfunc=None,
+                     histfunc='sum',
                      histnorm=None,
                      filename='histogram',
-                     create_html=True
+                     create_html=True,
+                     orientation='v'
                      ):
     """
 
-    :param df:
-    :param numeric_cols:
-    :param nbins:
-    :param marginal:
-    :param cumulative:
-    :param histfunc:
-    :param histnorm:
-    :param filename:
+    :param df: pandas dataframe
+    :param numeric_cols:list of columns with numeric columns
+    :param nbins:int, number of bins
+    :param marginal:str, marginal must be one of 'rug','box','violin','histogram
+    :param cumulative:bool
+    :param histfunc:str, histfunc must be one of 'count', 'sum', 'avg','min','max'
+    :param histnorm:str, normalization method for histogram 'percent','probability','density','probability density'
+    :param filename: filename:str, name of file, the extension must be excluded
     :param create_html: boolean, whether to create an html file or not
+    :param orientation: str, the orientation of the figure, 'v' or 'h'
     :return:
     """
     assert isinstance(df, pd.DataFrame), "df must be a pandas dataframe"
     assert isinstance(numeric_cols, list), "numeric_cols must be a list"
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
     assert isinstance(create_html, bool), "create_html must be a boolean"
+    assert isinstance(nbins, int), "nbins must be an integer"
+    assert isinstance(cumulative, bool), "cumulative must be a boolean"
+    assert marginal in ['rug','box','violin','histogram',None], "marginal must be one of 'rug','box','violin','histogram'"
+    assert '.' not in filename, "filename doesn't need an extension"
+    assert isinstance(histfunc, str),"histfunc must be a string"
+    assert isinstance(orientation,str)
+    assert orientation in ['v','h']
+    assert histnorm in ['percent','probability','density','probability density',None]
+    assert histfunc in ['count', 'sum', 'avg','min','max'], "histfunc must be one of 'count', 'sum', 'avg','min','max' "
 
     figure_list = list()
 
-    for col in numeric_cols:
-        plot = px.histogram(data_frame=df,
-                            nbins=nbins,
-                            x=col,
-                            marginal=marginal,
-                            cumulative=cumulative,
-                            histfunc=histfunc,
-                            histnorm=histnorm,
-                            title='Distribution of {}'.format(col)
-                            )
-        figure_list.append(plot)
+    if check_numeric(df=df,column_list=numeric_cols):
+        for col in numeric_cols:
+            plot = px.histogram(data_frame=df,
+                                nbins=nbins,
+                                x=col,
+                                marginal=marginal,
+                                cumulative=cumulative,
+                                histfunc=histfunc,
+                                histnorm=histnorm,
+                                orientation=orientation,
+                                title='Distribution of {}'.format(col)
+                                )
+            figure_list.append(plot)
 
     if create_html:
         figures_to_html(figs=figure_list, filename=filename)
@@ -381,6 +443,7 @@ def create_scatter(df,
                                         "name as keys and column type as value"
     assert isinstance(create_html, bool), "create_html must be a boolean"
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
+    assert '.' not in filename, "filename doesn't need an extension"
     numeric_cols = col_types['numeric']
     plot_pairs = create_pairs(df, numeric_cols=numeric_cols)
 
